# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ColumnRuleAssetCreatorInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_index: int
    _column_index_data_id: Optional[int]
    _description: Optional[str]
    _identity_id: Optional[str]
    _is_root: Optional[bool]
    _permission_string: Optional[str]
    _scoped_to: Optional[str]


    def __init__(
        self,
        column_index: Optional[int] = None,
        column_index_data_id: Optional[int] = None,
        description: Optional[str] = None,
        identity_id: Optional[str] = None,
        is_root: Optional[bool] = None,
        permission_string: Optional[str] = None,
        scoped_to: Optional[str] = None,
    ) -> None: ...

    @property
    def column_index(self) -> int: ...

    @column_index.setter
    def column_index(self, column_index: int) -> None: ...

    @property
    def column_index_data_id(self) -> Optional[int]: ...

    @column_index_data_id.setter
    def column_index_data_id(self, column_index_data_id: Optional[int]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def identity_id(self) -> Optional[str]: ...

    @identity_id.setter
    def identity_id(self, identity_id: Optional[str]) -> None: ...

    @property
    def is_root(self) -> Optional[bool]: ...

    @is_root.setter
    def is_root(self, is_root: Optional[bool]) -> None: ...

    @property
    def permission_string(self) -> Optional[str]: ...

    @permission_string.setter
    def permission_string(self, permission_string: Optional[str]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ValidateCronOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _error: Optional[str]
    _next_run_time: Optional[str]
    _quartz_cron_expression: Optional[str]
    _quartz_cron_expression_summary: Optional[str]
    _valid: Optional[bool]


    def __init__(
        self,
        error: Optional[str] = None,
        next_run_time: Optional[str] = None,
        quartz_cron_expression: Optional[str] = None,
        quartz_cron_expression_summary: Optional[str] = None,
        valid: Optional[bool] = False,
    ) -> None: ...

    @property
    def error(self) -> Optional[str]: ...

    @error.setter
    def error(self, error: Optional[str]) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def quartz_cron_expression(self) -> Optional[str]: ...

    @quartz_cron_expression.setter
    def quartz_cron_expression(self, quartz_cron_expression: Optional[str]) -> None: ...

    @property
    def quartz_cron_expression_summary(self) -> Optional[str]: ...

    @quartz_cron_expression_summary.setter
    def quartz_cron_expression_summary(self, quartz_cron_expression_summary: Optional[str]) -> None: ...

    @property
    def valid(self) -> Optional[bool]: ...

    @valid.setter
    def valid(self, valid: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleSetItemPropertyInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index_item': 'int',
        'column_index_value': 'int',
        'property_name': 'str'
    }

    attribute_map = {
        'column_index_item': 'columnIndexItem',
        'column_index_value': 'columnIndexValue',
        'property_name': 'propertyName'
    }

    def __init__(self, column_index_item=None, column_index_value=None, property_name=None):
        """
        ColumnRuleSetItemPropertyInputV1 - a model defined in Swagger
        """

        self._column_index_item = None
        self._column_index_value = None
        self._property_name = None

        if column_index_item is not None:
          self.column_index_item = column_index_item
        if column_index_value is not None:
          self.column_index_value = column_index_value
        if property_name is not None:
          self.property_name = property_name

    @property
    def column_index_item(self):
        """
        Gets the column_index_item of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that references the item. The column index is 1-based

        :return: The column_index_item of this ColumnRuleSetItemPropertyInputV1.
        :rtype: int
        """
        return self._column_index_item

    @column_index_item.setter
    def column_index_item(self, column_index_item):
        """
        Sets the column_index_item of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that references the item. The column index is 1-based

        :param column_index_item: The column_index_item of this ColumnRuleSetItemPropertyInputV1.
        :type: int
        """
        if column_index_item is None:
            raise ValueError("Invalid value for `column_index_item`, must not be `None`")

        self._column_index_item = column_index_item

    @property
    def column_index_value(self):
        """
        Gets the column_index_value of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that contains the value to set for the property. The column index is 1-based

        :return: The column_index_value of this ColumnRuleSetItemPropertyInputV1.
        :rtype: int
        """
        return self._column_index_value

    @column_index_value.setter
    def column_index_value(self, column_index_value):
        """
        Sets the column_index_value of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that contains the value to set for the property. The column index is 1-based

        :param column_index_value: The column_index_value of this ColumnRuleSetItemPropertyInputV1.
        :type: int
        """
        if column_index_value is None:
            raise ValueError("Invalid value for `column_index_value`, must not be `None`")

        self._column_index_value = column_index_value

    @property
    def property_name(self):
        """
        Gets the property_name of this ColumnRuleSetItemPropertyInputV1.
        The property to set on an item

        :return: The property_name of this ColumnRuleSetItemPropertyInputV1.
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """
        Sets the property_name of this ColumnRuleSetItemPropertyInputV1.
        The property to set on an item

        :param property_name: The property_name of this ColumnRuleSetItemPropertyInputV1.
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")

        self._property_name = property_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleSetItemPropertyInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PutScalarsInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _datasource_class: str
    _datasource_id: str
    _force_calculated_scalars: Optional[bool]
    _scalars: List[PutScalarInputV1]


    def __init__(
        self,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        force_calculated_scalars: Optional[bool] = False,
        scalars: Optional[List[PutScalarInputV1]] = None,
    ) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def force_calculated_scalars(self) -> Optional[bool]: ...

    @force_calculated_scalars.setter
    def force_calculated_scalars(self, force_calculated_scalars: Optional[bool]) -> None: ...

    @property
    def scalars(self) -> List[PutScalarInputV1]: ...

    @scalars.setter
    def scalars(self, scalars: List[PutScalarInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
